==> edge-login-ui-rn-3.22.2.tgz: package/lib/hooks/useCreateAccount.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { loadTouchState } from '../actions/TouchActions';
import { retryOnChallenge } from '../components/modals/ChallengeModal';
import { enableTouchId } from '../keychain';
import { useDispatch, useSelector } from '../types/ReduxTypes';
import { useHandler } from './useHandler';
import { useImports } from './useImports';
export const useCreateAccountHandler = () => {
    var _a;
    const { context, accountOptions } = useImports();
    const dispatch = useDispatch();
    const challengeId = (_a = useSelector(state => state.createChallengeId)) !== null && _a !== void 0 ? _a : undefined;
    const handleCreateAccount = useHandler((createAccountParams) => __awaiter(void 0, void 0, void 0, function* () {
        const { username, password, pin } = createAccountParams;
        return yield retryOnChallenge({
            task() {
                return __awaiter(this, void 0, void 0, function* () {
                    const account = yield context.createAccount(Object.assign(Object.assign({}, accountOptions), { challengeId,
                        username,
                        password,
                        pin }));
                    account.watch('loggedIn', loggedIn => {
                        if (!loggedIn)
                            dispatch({ type: 'RESET_APP' });
                    });
                    yield enableTouchId(account).catch(e => {
                        console.log(e); // Fail quietly
                    });
                    dispatch(loadTouchState());
                    return account;
                });
            },
            onCancel() { }
        });
    }));
    return handleCreateAccount;
};

==> edge-login-ui-rn-3.22.5.tgz: package/lib/hooks/useCreateAccount.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { loadTouchState } from '../actions/TouchActions';
import { retryOnChallenge } from '../components/modals/ChallengeModal';
import { enableTouchId } from '../keychain';
import { useDispatch, useSelector } from '../types/ReduxTypes';
import { useHandler } from './useHandler';
import { useImports } from './useImports';
export const useCreateAccountHandler = () => {
    var _a;
    const { context, accountOptions } = useImports();
    const dispatch = useDispatch();
    const savedChallengeId = (_a = useSelector(state => state.createChallengeId)) !== null && _a !== void 0 ? _a : undefined;
    const handleCreateAccount = useHandler((createAccountParams) => __awaiter(void 0, void 0, void 0, function* () {
        const { username, password, pin } = createAccountParams;
        return yield retryOnChallenge({
            cancelValue: undefined,
            task(challengeId = savedChallengeId) {
                return __awaiter(this, void 0, void 0, function* () {
                    const account = yield context.createAccount(Object.assign(Object.assign({}, accountOptions), { challengeId,
                        username,
                        password,
                        pin }));
                    account.watch('loggedIn', loggedIn => {
                        if (!loggedIn)
                            dispatch({ type: 'RESET_APP' });
                    });
                    yield enableTouchId(account).catch(e => {
                        console.log(e); // Fail quietly
                    });
                    dispatch(loadTouchState());
                    return account;
                });
            }
        });
    }));
    return handleCreateAccount;
};
